@@ -198,6 +198,7 @@ namespace stan {
                                 function_signature_t& signature);
       bool is_defined(const std::string& name,
                       const function_signature_t& sig);
+      bool has_user_defined_key(const std::string& name) const;
       std::set<std::string> key_set() const;
       bool has_key(const std::string& key) const;
 
@@ -447,12 +448,11 @@ namespace stan {
       expression true_val_;
       expression false_val_;
       expr_type type_;
-      var_origin origin_;
+      bool has_var_;
       conditional_op();
       conditional_op(const expression& cond,
                      const expression& true_val,
                      const expression& false_val);
-      bool is_data() const;
     };
 
     struct binary_op {
@@ -1080,6 +1080,21 @@ namespace stan {
       bool operator()(const unary_op& e) const;
     };
 
+    /**
+     * Returns true if the specified expression contains a variable
+     * that is defined as a parameter, defined as a transformed
+     * parameter, or is a local variable that is not an integer.
+     *
+     * <p>Compare to <code>has_nonparam_var</code>, which is similar,
+     * but excludes variables declared as parameters.
+     *
+     * @param e Expression to test.
+     * @param var_map Variable mapping for origin and types of
+     * variables.
+     * @return true if expression contains a variable defined as as a
+     * parameter, defined as a transformedparameter, or is a local
+     * variable that is not an integer.
+     */
     bool has_var(const expression& e,
                  const variable_map& var_map);
 
@@ -1102,6 +1117,21 @@ namespace stan {
       bool operator()(const unary_op& e) const;
     };
 
+    /**
+     * Returns true if the specified expression contains a variable
+     * that is defined as a transformed parameter, or is a local
+     * variable that is not an integer.
+     *
+     * <p>Compare to <code>has_var</code>, which is similar, but
+     * includes variables declared as parameters.
+     *
+     * @param e Expression to test.
+     * @param var_map Variable mapping for origin and types of
+     * variables.
+     * @return true if expression contains a variable defined as a
+     * transformed parameter, or is a local variable that is not
+     * an integer.
+     */
     bool has_non_param_var(const expression& e,
                            const variable_map& var_map);
 
