@@ -13,9 +13,7 @@ namespace stan {
     template <typename T>
     inline fvar<T> acosh(const fvar<T>& x) {
       using ::acosh;
-      using stan::math::square;
       using std::sqrt;
-      using stan::math::NOT_A_NUMBER;
       return fvar<T>(acosh(x.val_),
                      x.d_ / sqrt(square(x.val_) - 1));
     }
