@@ -5,13 +5,12 @@
 #include <stan/math/prim/scal/fun/is_nan.hpp>
 
 namespace stan {
-
   namespace math {
 
     /**
      * Returns 1 if the input's value is NaN and 0 otherwise.
      *
-     * Delegates to <code>stan::math::is_nan</code>.
+     * Delegates to <code>is_nan</code>.
      *
      * @param x Value to test.
      * @return <code>1</code> if the value is NaN and <code>0</code> otherwise.
@@ -20,11 +19,9 @@ namespace stan {
     inline
     int
     is_nan(const fvar<T>& x) {
-      using stan::math::is_nan;
       return is_nan(x.val());
     }
 
   }
 }
-
 #endif
