@@ -28,7 +28,6 @@
 #include <stan/math/prim/mat/err/check_ldlt_factor.hpp>
 #include <stan/math/prim/mat/err/check_lower_triangular.hpp>
 #include <stan/math/prim/mat/err/check_matching_dims.hpp>
-#include <stan/math/prim/mat/err/check_matching_sizes.hpp>
 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
 #include <stan/math/prim/mat/err/check_ordered.hpp>
 #include <stan/math/prim/mat/err/check_pos_definite.hpp>
@@ -159,7 +158,8 @@
 #include <stan/math/prim/mat/fun/singular_values.hpp>
 #include <stan/math/prim/mat/fun/size.hpp>
 #include <stan/math/prim/mat/fun/softmax.hpp>
-#include <stan/math/prim/mat/fun/sort.hpp>
+#include <stan/math/prim/mat/fun/sort_asc.hpp>
+#include <stan/math/prim/mat/fun/sort_desc.hpp>
 #include <stan/math/prim/mat/fun/sort_indices.hpp>
 #include <stan/math/prim/mat/fun/sort_indices_asc.hpp>
 #include <stan/math/prim/mat/fun/sort_indices_desc.hpp>
