@@ -21,7 +21,6 @@
 #include <stan/math/prim/mat/fun/tcrossprod.hpp>
 #include <stan/math/prim/mat/fun/trace_quad_form.hpp>
 #include <stan/math/prim/mat/fun/transpose.hpp>
-
 #include <stan/math/prim/scal/fun/constants.hpp>
 #include <stan/math/prim/scal/meta/include_summand.hpp>
 
@@ -89,35 +88,18 @@ namespace stan {
                          const Eigen::Matrix<T_m0, Eigen::Dynamic, 1>& m0,
                          const Eigen::Matrix
                          <T_C0, Eigen::Dynamic, Eigen::Dynamic>& C0) {
-      static const char* function("stan::math::gaussian_dlm_obs_log");
+      static const char* function("gaussian_dlm_obs_log");
       typedef typename return_type<
         T_y,
         typename return_type<T_F, T_G, T_V, T_W, T_m0, T_C0>::type>::type T_lp;
       T_lp lp(0.0);
 
-      using stan::math::add;
-      using stan::math::check_cov_matrix;
-      using stan::math::check_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_size_match;
-      using stan::math::check_spsd_matrix;
-      using stan::math::check_square;
-      using stan::math::inverse_spd;
-      using stan::math::log_determinant_spd;
-      using stan::math::multiply;
-      using stan::math::quad_form_sym;
-      using stan::math::subtract;
-      using stan::math::trace_quad_form;
-      using stan::math::transpose;
-
       int r = y.rows();  // number of variables
       int T = y.cols();  // number of observations
       int n = G.rows();  // number of states
 
-      // check y
       check_finite(function, "y", y);
       check_not_nan(function, "y", y);
-      // check F
       check_size_match(function,
                        "columns of F", F.cols(),
                        "rows of y", y.rows());
@@ -125,29 +107,24 @@ namespace stan {
                        "rows of F", F.rows(),
                        "rows of G", G.rows());
       check_finite(function, "F", F);
-      // check G
       check_square(function, "G", G);
       check_finite(function, "G", G);
-      // check V
       check_size_match(function,
                        "rows of V", V.rows(),
                        "rows of y", y.rows());
       // TODO(anyone): incorporate support for infinite V
       check_finite(function, "V", V);
       check_spsd_matrix(function, "V", V);
-      // check W
       check_size_match(function,
                        "rows of W", W.rows(),
                        "rows of G", G.rows());
       // TODO(anyone): incorporate support for infinite W
       check_finite(function, "W", W);
       check_spsd_matrix(function, "W", W);
-      // check m0
       check_size_match(function,
                        "size of m0", m0.size(),
                        "rows of G", G.rows());
       check_finite(function, "m0", m0);
-      // check C0
       check_size_match(function,
                        "rows of C0", C0.rows(),
                        "rows of G", G.rows());
@@ -294,37 +271,21 @@ namespace stan {
                          const Eigen::Matrix<T_m0, Eigen::Dynamic, 1>& m0,
                          const Eigen::Matrix
                          <T_C0, Eigen::Dynamic, Eigen::Dynamic>& C0) {
-      static const char* function("stan::math::gaussian_dlm_obs_log");
+      static const char* function("gaussian_dlm_obs_log");
       typedef
         typename return_type
         <T_y, typename return_type<T_F, T_G, T_V, T_W, T_m0, T_C0>::type>::type
         T_lp;
       T_lp lp(0.0);
 
-      using stan::math::add;
-      using stan::math::check_cov_matrix;
-      using stan::math::check_finite;
-      using stan::math::check_nonnegative;
-      using stan::math::check_not_nan;
-      using stan::math::check_size_match;
-      using stan::math::check_spsd_matrix;
-      using stan::math::dot_product;
-      using stan::math::multiply;
-      using stan::math::quad_form_sym;
-      using stan::math::subtract;
-      using stan::math::tcrossprod;
-      using stan::math::trace_quad_form;
-      using stan::math::transpose;
       using std::log;
 
       int r = y.rows();  // number of variables
       int T = y.cols();  // number of observations
       int n = G.rows();  // number of states
 
-      // check y
       check_finite(function, "y", y);
       check_not_nan(function, "y", y);
-      // check F
       check_size_match(function,
                        "columns of F", F.cols(),
                        "rows of y", y.rows());
@@ -333,13 +294,11 @@ namespace stan {
                        "rows of G", G.rows());
       check_finite(function, "F", F);
       check_not_nan(function, "F", F);
-      // check G
       check_size_match(function,
                        "rows of G", G.rows(),
                        "columns of G", G.cols());
       check_finite(function, "G", G);
       check_not_nan(function, "G", G);
-      // check V
       check_nonnegative(function, "V", V);
       check_size_match(function,
                        "size of V", V.size(),
@@ -347,7 +306,6 @@ namespace stan {
       // TODO(anyone): support infinite V
       check_finite(function, "V", V);
       check_not_nan(function, "V", V);
-      // check W
       check_spsd_matrix(function, "W", W);
       check_size_match(function,
                        "rows of W", W.rows(),
@@ -355,13 +313,11 @@ namespace stan {
       // TODO(anyone): support infinite W
       check_finite(function, "W", W);
       check_not_nan(function, "W", W);
-      // check m0
       check_size_match(function,
                        "size of m0", m0.size(),
                        "rows of G", G.rows());
       check_finite(function, "m0", m0);
       check_not_nan(function, "m0", m0);
-      // check C0
       check_cov_matrix(function, "C0", C0);
       check_size_match(function,
                        "rows of C0", C0.rows(),
@@ -408,19 +364,19 @@ namespace stan {
             for (int k = 0; k < F.rows(); ++k) {
               Fj(k) = F(k, j);
             }
-            // // f_{t, i} = F_{t, i}' m_{t, i-1}
+            // f_{t, i} = F_{t, i}' m_{t, i-1}
             f = dot_product(Fj, m);
             Q = trace_quad_form(C, Fj) + V(j);
             Q_inv = 1.0 / Q;
-            // // filtered observation
-            // // e_{t, i} = y_{t, i} - f_{t, i}
+            // filtered observation
+            // e_{t, i} = y_{t, i} - f_{t, i}
             e = yij - f;
-            // // A_{t, i} = C_{t, i-1} F_{t, i} Q_{t, i}^{-1}
+            // A_{t, i} = C_{t, i-1} F_{t, i} Q_{t, i}^{-1}
             A = multiply(multiply(C, Fj), Q_inv);
-            // // m_{t, i} = m_{t, i-1} + A_{t, i} e_{t, i}
+            // m_{t, i} = m_{t, i-1} + A_{t, i} e_{t, i}
             m += multiply(A, e);
-            // // c_{t, i} = C_{t, i-1} - Q_{t, i} A_{t, i} A_{t, i}'
-            // // // tcrossprod throws an error (ambiguous)
+            // c_{t, i} = C_{t, i-1} - Q_{t, i} A_{t, i} A_{t, i}'
+            // tcrossprod throws an error (ambiguous)
             // C = subtract(C, multiply(Q, tcrossprod(A)));
             C -= multiply(Q, multiply(A, transpose(A)));
             C = 0.5 * add(C, transpose(C));
@@ -448,8 +404,7 @@ namespace stan {
      const Eigen::Matrix<T_C0, Eigen::Dynamic, Eigen::Dynamic>& C0) {
       return gaussian_dlm_obs_log<false>(y, F, G, V, W, m0, C0);
     }
+
   }
-
 }
-
 #endif
