@@ -1,17 +1,13 @@
 #ifndef STAN_MATH_PRIM_SCAL_FUN_INV_SQRT_HPP
 #define STAN_MATH_PRIM_SCAL_FUN_INV_SQRT_HPP
 
-#include <boost/math/tools/promotion.hpp>
+#include <cmath>
 
 namespace stan {
   namespace math {
 
-    template <typename T>
-    inline
-    typename boost::math::tools::promote_args<T>::type
-    inv_sqrt(const T x) {
+    inline double inv_sqrt(const double x) {
       using std::sqrt;
-
       return 1.0 / sqrt(x);
     }
 
