@@ -5,7 +5,6 @@
 #include <stan/math/prim/scal/fun/logit.hpp>
 
 namespace stan {
-
   namespace math {
 
     /**
@@ -25,15 +24,12 @@ namespace stan {
     template <typename T>
     inline
     T prob_free(const T y) {
-      using stan::math::logit;
-      stan::math::check_bounded<T, double, double>
-        ("stan::math::prob_free", "Probability variable",
+      check_bounded<T, double, double>
+        ("prob_free", "Probability variable",
          y, 0, 1);
       return logit(y);
     }
 
   }
-
 }
-
 #endif
