@@ -17,7 +17,6 @@
 #include <stan/math/prim/scal/fun/grad_F32.hpp>
 
 namespace stan {
-
   namespace math {
 
     template <class RNG>
@@ -26,10 +25,7 @@ namespace stan {
                       const double alpha,
                       const double beta,
                       RNG& rng) {
-      static const char* function("stan::math::beta_binomial_rng");
-
-      using stan::math::check_positive_finite;
-      using stan::math::check_nonnegative;
+      static const char* function("beta_binomial_rng");
 
       check_nonnegative(function, "Population size parameter", N);
       check_positive_finite(function,
@@ -37,11 +33,12 @@ namespace stan {
       check_positive_finite(function,
                             "Second prior sample size parameter", beta);
 
-      double a = stan::math::beta_rng(alpha, beta, rng);
+      double a = beta_rng(alpha, beta, rng);
       while (a > 1 || a < 0)
-        a = stan::math::beta_rng(alpha, beta, rng);
-      return stan::math::binomial_rng(N, a, rng);
+        a = beta_rng(alpha, beta, rng);
+      return binomial_rng(N, a, rng);
     }
+
   }
 }
 #endif
