@@ -24,9 +24,7 @@
 #include <boost/random/binomial_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
 
-
 namespace stan {
-
   namespace math {
 
     // Binomial(n|N, theta)  [N >= 0;  0 <= n <= N;  0 <= theta <= 1]
@@ -41,16 +39,8 @@ namespace stan {
       typedef typename stan::partials_return_type<T_n, T_N, T_prob>::type
         T_partials_return;
 
-      static const char* function("stan::math::binomial_log");
+      static const char* function("binomial_log");
 
-      using stan::math::check_finite;
-      using stan::math::check_bounded;
-      using stan::math::check_nonnegative;
-      using stan::math::value_of;
-      using stan::math::check_consistent_sizes;
-      using stan::math::include_summand;
-
-      // check if any vectors are zero length
       if (!(stan::length(n)
             && stan::length(N)
             && stan::length(theta)))
@@ -66,12 +56,9 @@ namespace stan {
                              "Population size parameter", N,
                              "Probability parameter", theta);
 
-
-      // check if no variables are involved and prop-to
       if (!include_summand<propto, T_prob>::value)
         return 0.0;
 
-      // set up template expressions wrapping scalars into vector views
       VectorView<const T_n> n_vec(n);
       VectorView<const T_N> N_vec(N);
       VectorView<const T_prob> theta_vec(theta);
@@ -79,10 +66,6 @@ namespace stan {
 
       OperandsAndPartials<T_prob> operands_and_partials(theta);
 
-      using stan::math::multiply_log;
-      using stan::math::binomial_coefficient_log;
-      using stan::math::log1m;
-
       if (include_summand<propto>::value) {
         for (size_t i = 0; i < size; ++i)
           logp += binomial_coefficient_log(N_vec[i], n_vec[i]);
@@ -92,7 +75,6 @@ namespace stan {
       for (size_t i = 0; i < length(theta); ++i)
         log1m_theta[i] = log1m(value_of(theta_vec[i]));
 
-      // no test for include_summand because return if not live
       for (size_t i = 0; i < size; ++i)
         logp += multiply_log(n_vec[i], value_of(theta_vec[i]))
           + (N_vec[i] - n_vec[i]) * log1m_theta[i];
