@@ -18,7 +18,6 @@
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     template <typename T_y, typename T_loc, typename T_scale>
@@ -27,19 +26,13 @@ namespace stan {
       typedef typename stan::partials_return_type<T_y, T_loc, T_scale>::type
         T_partials_return;
 
-      // Size checks
       if ( !( stan::length(y) && stan::length(mu)
               && stan::length(sigma) ) )
         return 0.0;
 
-      static const char* function("stan::math::cauchy_cdf");
+      static const char* function("cauchy_cdf");
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
       using boost::math::tools::promote_args;
-      using stan::math::value_of;
 
       T_partials_return ccdf_log(0.0);
 
@@ -51,7 +44,6 @@ namespace stan {
                              "Location parameter", mu,
                              "Scale Parameter", sigma);
 
-      // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
       VectorView<const T_loc> mu_vec(mu);
       VectorView<const T_scale> sigma_vec(sigma);
@@ -60,21 +52,16 @@ namespace stan {
       OperandsAndPartials<T_y, T_loc, T_scale>
         operands_and_partials(y, mu, sigma);
 
-      // Compute CDFLog and its gradients
       using std::atan;
-      using stan::math::pi;
       using std::log;
 
-      // Compute vectorized CDF and gradient
       for (size_t n = 0; n < N; n++) {
-        // Pull out values
         const T_partials_return y_dbl = value_of(y_vec[n]);
         const T_partials_return mu_dbl = value_of(mu_vec[n]);
         const T_partials_return sigma_inv_dbl = 1.0 / value_of(sigma_vec[n]);
         const T_partials_return sigma_dbl = value_of(sigma_vec[n]);
         const T_partials_return z = (y_dbl - mu_dbl) * sigma_inv_dbl;
 
-        // Compute
         const T_partials_return Pn = 0.5 - atan(z) / pi();
         ccdf_log += log(Pn);
 
@@ -90,6 +77,7 @@ namespace stan {
       }
       return operands_and_partials.value(ccdf_log);
     }
+
   }
 }
 #endif
