@@ -18,7 +18,6 @@
 #include <limits>
 
 namespace stan {
-
   namespace math {
 
     /**
@@ -39,19 +38,13 @@ namespace stan {
       typedef typename stan::partials_return_type<T_y, T_loc, T_scale>::type
         T_partials_return;
 
-      // Size checks
       if ( !( stan::length(y) && stan::length(mu)
               && stan::length(sigma) ) )
         return 1.0;
 
-      static const char* function("stan::math::cauchy_cdf");
+      static const char* function("cauchy_cdf");
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
       using boost::math::tools::promote_args;
-      using stan::math::value_of;
 
       T_partials_return P(1.0);
 
@@ -63,7 +56,6 @@ namespace stan {
                              "Location parameter", mu,
                              "Scale Parameter", sigma);
 
-      // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
       VectorView<const T_loc> mu_vec(mu);
       VectorView<const T_scale> sigma_vec(sigma);
@@ -79,11 +71,8 @@ namespace stan {
           return operands_and_partials.value(0.0);
       }
 
-      // Compute CDF and its gradients
       using std::atan;
-      using stan::math::pi;
 
-      // Compute vectorized CDF and gradient
       for (size_t n = 0; n < N; n++) {
         // Explicit results for extreme values
         // The gradients are technically ill-defined, but treated as zero
@@ -91,14 +80,12 @@ namespace stan {
           continue;
         }
 
-        // Pull out values
         const T_partials_return y_dbl = value_of(y_vec[n]);
         const T_partials_return mu_dbl = value_of(mu_vec[n]);
         const T_partials_return sigma_inv_dbl = 1.0 / value_of(sigma_vec[n]);
 
         const T_partials_return z = (y_dbl - mu_dbl) * sigma_inv_dbl;
 
-        // Compute
         const T_partials_return Pn = atan(z) / pi() + 0.5;
 
         P *= Pn;
@@ -126,9 +113,9 @@ namespace stan {
         for (size_t n = 0; n < stan::length(sigma); ++n)
           operands_and_partials.d_x3[n] *= P;
       }
-
       return operands_and_partials.value(P);
     }
+
   }
 }
 #endif
