@@ -14,11 +14,9 @@
 #include <stan/math/prim/scal/meta/include_summand.hpp>
 #include <stan/math/prim/scal/fun/value_of.hpp>
 #include <boost/random/normal_distribution.hpp>
-#include <boost/math/special_functions/fpclassify.hpp>
 #include <boost/random/variate_generator.hpp>
 
 namespace stan {
-
   namespace math {
 
     template <class RNG>
@@ -27,21 +25,17 @@ namespace stan {
                        const double sigma,
                        const double lambda,
                        RNG& rng) {
-      static const char* function("stan::math::exp_mod_normal_rng");
-
-      using stan::math::check_positive_finite;
-      using stan::math::check_finite;
+      static const char* function("exp_mod_normal_rng");
 
       check_finite(function, "Location parameter", mu);
       check_positive_finite(function, "Inv_scale parameter", lambda);
       check_positive_finite(function, "Scale parameter", sigma);
 
-      return stan::math::normal_rng(mu, sigma, rng)
-        + stan::math::exponential_rng(lambda, rng);
+      return normal_rng(mu, sigma, rng)
+        + exponential_rng(lambda, rng);
     }
+
   }
 }
 #endif
 
-
-
