@@ -22,7 +22,6 @@
 #include <stan/math/prim/scal/fun/grad_reg_inc_gamma.hpp>
 
 namespace stan {
-
   namespace math {
 
     template <class RNG>
@@ -33,10 +32,7 @@ namespace stan {
       using boost::variate_generator;
       using boost::gamma_distribution;
 
-      static const char* function("stan::math::gamma_rng");
-
-      using stan::math::check_positive_finite;
-
+      static const char* function("gamma_rng");
       check_positive_finite(function, "Shape parameter", alpha);
       check_positive_finite(function, "Inverse scale parameter", beta);
 
@@ -52,5 +48,4 @@ namespace stan {
 
   }
 }
-
 #endif
