@@ -27,7 +27,6 @@
 #include <limits>
 
 namespace stan {
-
   namespace math {
 
     /**
@@ -52,20 +51,11 @@ namespace stan {
       typedef typename stan::partials_return_type<T_y, T_shape, T_scale>::type
         T_partials_return;
 
-      // Size checks
       if (!(stan::length(y) && stan::length(alpha) && stan::length(beta)))
         return 1.0;
 
-      // Error checks
-      static const char* function("stan::math::inv_gamma_cdf");
+      static const char* function("inv_gamma_cdf");
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
-      using stan::math::check_greater_or_equal;
-      using stan::math::check_less_or_equal;
-      using stan::math::check_nonnegative;
-      using stan::math::value_of;
       using boost::math::tools::promote_args;
       using std::exp;
 
@@ -80,7 +70,6 @@ namespace stan {
                              "Shape parameter", alpha,
                              "Scale Parameter", beta);
 
-      // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
       VectorView<const T_shape> alpha_vec(alpha);
       VectorView<const T_scale> beta_vec(beta);
@@ -91,20 +80,15 @@ namespace stan {
 
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
-
       for (size_t i = 0; i < stan::length(y); i++) {
         if (value_of(y_vec[i]) == 0)
           return operands_and_partials.value(0.0);
       }
 
-      // Compute CDF and its gradients
-      using stan::math::gamma_q;
-      using stan::math::digamma;
       using boost::math::tgamma;
       using std::exp;
       using std::pow;
 
-      // Cache a few expensive function calls if nu is a parameter
       VectorBuilder<!is_constant_struct<T_shape>::value,
                     T_partials_return, T_shape>
         gamma_vec(stan::length(alpha));
@@ -120,20 +104,17 @@ namespace stan {
         }
       }
 
-      // Compute vectorized CDF and gradient
       for (size_t n = 0; n < N; n++) {
         // Explicit results for extreme values
         // The gradients are technically ill-defined, but treated as zero
         if (value_of(y_vec[n]) == std::numeric_limits<double>::infinity())
           continue;
 
-        // Pull out values
         const T_partials_return y_dbl = value_of(y_vec[n]);
         const T_partials_return y_inv_dbl = 1.0 / y_dbl;
         const T_partials_return alpha_dbl = value_of(alpha_vec[n]);
         const T_partials_return beta_dbl = value_of(beta_vec[n]);
 
-        // Compute
         const T_partials_return Pn = gamma_q(alpha_dbl, beta_dbl * y_inv_dbl);
 
         P *= Pn;
@@ -145,9 +126,9 @@ namespace stan {
             / tgamma(alpha_dbl) / Pn;
         if (!is_constant_struct<T_shape>::value)
           operands_and_partials.d_x2[n]
-            += stan::math::grad_reg_inc_gamma(alpha_dbl, beta_dbl
-                                              * y_inv_dbl, gamma_vec[n],
-                                              digamma_vec[n]) / Pn;
+            += grad_reg_inc_gamma(alpha_dbl, beta_dbl
+                                  * y_inv_dbl, gamma_vec[n],
+                                  digamma_vec[n]) / Pn;
         if (!is_constant_struct<T_scale>::value)
           operands_and_partials.d_x3[n] += - y_inv_dbl
             * exp(-beta_dbl * y_inv_dbl)
@@ -167,10 +148,9 @@ namespace stan {
         for (size_t n = 0; n < stan::length(beta); ++n)
           operands_and_partials.d_x3[n] *= P;
       }
-
       return operands_and_partials.value(P);
     }
+
   }
 }
-
 #endif
