@@ -11,7 +11,6 @@
 #include <stan/math/prim/scal/fun/value_of.hpp>
 
 namespace stan {
-
   namespace math {
 
     template <class RNG>
@@ -21,11 +20,8 @@ namespace stan {
                RNG& rng) {
       using boost::variate_generator;
       using boost::normal_distribution;
-      using stan::math::check_positive;
-      using stan::math::check_finite;
-      using stan::math::check_not_nan;
 
-      static const char* function("stan::math::normal_rng");
+      static const char* function("normal_rng");
 
       check_finite(function, "Location parameter", mu);
       check_not_nan(function, "Location parameter", mu);
@@ -36,6 +32,7 @@ namespace stan {
         norm_rng(rng, normal_distribution<>(mu, sigma));
       return norm_rng();
     }
+
   }
 }
 #endif
