@@ -12,7 +12,6 @@
 #include <stan/math/prim/scal/fun/multiply_log.hpp>
 #include <stan/math/prim/scal/fun/value_of.hpp>
 
-
 namespace stan {
   namespace math {
 
@@ -24,9 +23,7 @@ namespace stan {
       using boost::variate_generator;
       using boost::exponential_distribution;
 
-      static const char* function("stan::math::pareto_rng");
-
-      using stan::math::check_positive_finite;
+      static const char* function("pareto_rng");
 
       check_positive_finite(function, "Scale parameter", y_min);
       check_positive_finite(function, "Shape parameter", alpha);
@@ -35,6 +32,7 @@ namespace stan {
         exp_rng(rng, exponential_distribution<>(alpha));
       return y_min * std::exp(exp_rng());
     }
+
   }
 }
 #endif
