@@ -9,14 +9,12 @@
 #include <stan/math/prim/scal/fun/multiply_log.hpp>
 #include <stan/math/prim/scal/fun/gamma_q.hpp>
 #include <stan/math/prim/scal/fun/value_of.hpp>
-#include <boost/math/special_functions/fpclassify.hpp>
 #include <boost/random/poisson_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
 #include <cmath>
 #include <limits>
 
 namespace stan {
-
   namespace math {
 
     template <class RNG>
@@ -26,7 +24,7 @@ namespace stan {
       using boost::variate_generator;
       using boost::random::poisson_distribution;
 
-      static const char* function("stan::math::poisson_rng");
+      static const char* function("poisson_rng");
 
       check_not_nan(function, "Rate parameter", lambda);
       check_nonnegative(function, "Rate parameter", lambda);
@@ -36,6 +34,7 @@ namespace stan {
         poisson_rng(rng, poisson_distribution<>(lambda));
       return poisson_rng();
     }
+
   }
 }
 #endif
