@@ -20,29 +20,20 @@
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     template <typename T_y, typename T_scale>
     typename return_type<T_y, T_scale>::type
     rayleigh_cdf(const T_y& y, const T_scale& sigma) {
-      static const char* function("stan::math::rayleigh_cdf");
+      static const char* function("rayleigh_cdf");
       typedef typename stan::partials_return_type<T_y, T_scale>::type
         T_partials_return;
 
-      using stan::math::check_nonnegative;
-      using stan::math::check_positive;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
-      using stan::math::include_summand;
       using stan::is_constant_struct;
-      using stan::math::square;
-      using stan::math::value_of;
       using std::exp;
 
       T_partials_return cdf(1.0);
 
-      // check if any vectors are zero length
       if (!(stan::length(y) && stan::length(sigma)))
         return cdf;
 
@@ -54,8 +45,6 @@ namespace stan {
                              "Random variable", y,
                              "Scale parameter", sigma);
 
-
-      // set up template expressions wrapping scalars into vector views
       OperandsAndPartials<T_y, T_scale> operands_and_partials(y, sigma);
 
       VectorView<const T_y> y_vec(y);
@@ -77,7 +66,6 @@ namespace stan {
           cdf *= (1.0 - exp_val);
       }
 
-      // gradients
       for (size_t n = 0; n < N; n++) {
         const T_partials_return y_dbl = value_of(y_vec[n]);
         const T_partials_return y_sqr = square(y_dbl);
@@ -92,9 +80,9 @@ namespace stan {
           operands_and_partials.d_x2[n] -= y_sqr * inv_sigma_sqr
             * inv_sigma[n] * exp_div_1m_exp * cdf;
       }
-
       return operands_and_partials.value(cdf);
     }
+
   }
 }
 #endif
