@@ -24,9 +24,7 @@
 #include <limits>
 #include <cmath>
 
-
 namespace stan {
-
   namespace math {
 
     template <typename T_y, typename T_dof, typename T_scale>
@@ -36,17 +34,11 @@ namespace stan {
       typedef typename stan::partials_return_type<T_y, T_dof, T_scale>::type
         T_partials_return;
 
-      // Size checks
       if (!(stan::length(y) && stan::length(nu) && stan::length(s)))
         return 0.0;
 
-      static const char* function("stan::math::scaled_inv_chi_square_cdf_log");
+      static const char* function("scaled_inv_chi_square_cdf_log");
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
-      using stan::math::check_nonnegative;
-      using stan::math::value_of;
       using std::exp;
 
       T_partials_return P(0.0);
@@ -60,7 +52,6 @@ namespace stan {
                              "Degrees of freedom parameter", nu,
                              "Scale parameter", s);
 
-      // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
       VectorView<const T_dof> nu_vec(nu);
       VectorView<const T_scale> s_vec(s);
@@ -73,18 +64,14 @@ namespace stan {
       // The gradients are technically ill-defined, but treated as zero
       for (size_t i = 0; i < stan::length(y); i++) {
         if (value_of(y_vec[i]) == 0)
-          return operands_and_partials.value(stan::math::negative_infinity());
+          return operands_and_partials.value(negative_infinity());
       }
 
-      // Compute cdf_log and its gradients
-      using stan::math::gamma_q;
-      using stan::math::digamma;
       using boost::math::tgamma;
       using std::exp;
       using std::pow;
       using std::log;
 
-      // Cache a few expensive function calls if nu is a parameter
       VectorBuilder<!is_constant_struct<T_dof>::value,
                     T_partials_return, T_dof> gamma_vec(stan::length(nu));
       VectorBuilder<!is_constant_struct<T_dof>::value,
@@ -98,7 +85,6 @@ namespace stan {
         }
       }
 
-      // Compute vectorized cdf_log and gradient
       for (size_t n = 0; n < N; n++) {
         // Explicit results for extreme values
         // The gradients are technically ill-defined, but treated as zero
@@ -106,7 +92,6 @@ namespace stan {
           continue;
         }
 
-        // Pull out values
         const T_partials_return y_dbl = value_of(y_vec[n]);
         const T_partials_return y_inv_dbl = 1.0 / y_dbl;
         const T_partials_return half_nu_dbl = 0.5 * value_of(nu_vec[n]);
@@ -116,7 +101,6 @@ namespace stan {
         const T_partials_return half_nu_s2_overx_dbl
           = 2.0 * half_nu_dbl * half_s2_overx_dbl;
 
-        // Compute
         const T_partials_return Pn = gamma_q(half_nu_dbl, half_nu_s2_overx_dbl);
         const T_partials_return gamma_p_deriv = exp(-half_nu_s2_overx_dbl)
           * pow(half_nu_s2_overx_dbl, half_nu_dbl-1) / tgamma(half_nu_dbl);
@@ -128,19 +112,19 @@ namespace stan {
             * gamma_p_deriv / Pn;
         if (!is_constant_struct<T_dof>::value)
           operands_and_partials.d_x2[n]
-            += (0.5 * stan::math::grad_reg_inc_gamma(half_nu_dbl,
-                                                     half_nu_s2_overx_dbl,
-                                                     gamma_vec[n],
-                                                     digamma_vec[n])
+            += (0.5 * grad_reg_inc_gamma(half_nu_dbl,
+                                         half_nu_s2_overx_dbl,
+                                         gamma_vec[n],
+                                         digamma_vec[n])
                 - half_s2_overx_dbl * gamma_p_deriv)
             / Pn;
         if (!is_constant_struct<T_scale>::value)
           operands_and_partials.d_x3[n] += - 2.0 * half_nu_dbl * s_dbl
             * y_inv_dbl * gamma_p_deriv / Pn;
       }
-
       return operands_and_partials.value(P);
     }
+
   }
 }
 #endif
