@@ -17,30 +17,22 @@
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     template <typename T_y, typename T_low, typename T_high>
     typename return_type<T_y, T_low, T_high>::type
     uniform_cdf_log(const T_y& y, const T_low& alpha, const T_high& beta) {
-      static const char* function("stan::math::uniform_cdf_log");
+      static const char* function("uniform_cdf_log");
       typedef typename stan::partials_return_type<T_y, T_low, T_high>::type
         T_partials_return;
 
-      using stan::math::check_not_nan;
-      using stan::math::check_finite;
-      using stan::math::check_greater;
-      using stan::math::value_of;
-      using stan::math::check_consistent_sizes;
       using std::log;
 
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(alpha)
             && stan::length(beta)))
         return 0.0;
 
-      // set up return value accumulator
       T_partials_return cdf_log(0.0);
       check_not_nan(function, "Random variable", y);
       check_finite(function, "Lower bound parameter", alpha);
@@ -63,7 +55,7 @@ namespace stan {
         const T_partials_return y_dbl = value_of(y_vec[n]);
         if (y_dbl < value_of(alpha_vec[n])
             || y_dbl > value_of(beta_vec[n]))
-          return stan::math::negative_infinity();
+          return negative_infinity();
         if (y_dbl == value_of(beta_vec[n]))
           return operands_and_partials.value(0.0);
       }
@@ -75,10 +67,8 @@ namespace stan {
         const T_partials_return b_min_a = beta_dbl - alpha_dbl;
         const T_partials_return cdf_log_ = (y_dbl - alpha_dbl) / b_min_a;
 
-        // cdf_log
         cdf_log += log(cdf_log_);
 
-        // gradients
         if (!is_constant_struct<T_y>::value)
           operands_and_partials.d_x1[n] += 1.0 / b_min_a / cdf_log_;
         if (!is_constant_struct<T_low>::value)
@@ -87,9 +77,9 @@ namespace stan {
         if (!is_constant_struct<T_high>::value)
           operands_and_partials.d_x3[n] -= 1.0 / b_min_a;
       }
-
       return operands_and_partials.value(cdf_log);
     }
+
   }
 }
 #endif
