@@ -13,18 +13,18 @@ namespace stan {
       class bessel_first_kind_dv_vari : public op_dv_vari {
       public:
         bessel_first_kind_dv_vari(int a, vari* bvi) :
-          op_dv_vari(stan::math::bessel_first_kind(a, bvi->val_), a, bvi) {
+          op_dv_vari(bessel_first_kind(a, bvi->val_), a, bvi) {
         }
         void chain() {
           bvi_->adj_ += adj_
-            * (ad_ * stan::math::bessel_first_kind(ad_, bvi_->val_)
+            * (ad_ * bessel_first_kind(ad_, bvi_->val_)
                / bvi_->val_
-               - stan::math::bessel_first_kind(ad_ + 1, bvi_->val_));
+               - bessel_first_kind(ad_ + 1, bvi_->val_));
         }
       };
     }
 
-    inline var bessel_first_kind(const int& v,
+    inline var bessel_first_kind(int v,
                                  const var& a) {
       return var(new bessel_first_kind_dv_vari(v, a.vi_));
     }
