@@ -22,7 +22,7 @@ namespace stan {
           op_v_vari(::erf(avi->val_), avi) {
         }
         void chain() {
-          avi_->adj_ += adj_ * stan::math::TWO_OVER_SQRT_PI
+          avi_->adj_ += adj_ * TWO_OVER_SQRT_PI
             * std::exp(- avi_->val_ * avi_->val_);
         }
       };
