@@ -13,7 +13,7 @@ namespace stan {
       class falling_factorial_vv_vari : public op_vv_vari {
       public:
         falling_factorial_vv_vari(vari* avi, vari* bvi) :
-          op_vv_vari(stan::math::falling_factorial(avi->val_, bvi->val_),
+          op_vv_vari(falling_factorial(avi->val_, bvi->val_),
                      avi, bvi) {
         }
         void chain() {
@@ -30,7 +30,7 @@ namespace stan {
       class falling_factorial_vd_vari : public op_vd_vari {
       public:
         falling_factorial_vd_vari(vari* avi, double b) :
-          op_vd_vari(stan::math::falling_factorial(avi->val_, b), avi, b) {
+          op_vd_vari(falling_factorial(avi->val_, b), avi, b) {
         }
         void chain() {
           avi_->adj_ += adj_
@@ -43,7 +43,7 @@ namespace stan {
       class falling_factorial_dv_vari : public op_dv_vari {
       public:
         falling_factorial_dv_vari(double a, vari* bvi) :
-          op_dv_vari(stan::math::falling_factorial(a, bvi->val_), a, bvi) {
+          op_dv_vari(falling_factorial(a, bvi->val_), a, bvi) {
         }
         void chain() {
           bvi_->adj_ += adj_
@@ -54,7 +54,7 @@ namespace stan {
     }
 
     inline var falling_factorial(const var& a,
-                                 const double& b) {
+                                 double b) {
       return var(new falling_factorial_vd_vari(a.vi_, b));
     }
 
@@ -63,10 +63,11 @@ namespace stan {
       return var(new falling_factorial_vv_vari(a.vi_, b.vi_));
     }
 
-    inline var falling_factorial(const double& a,
+    inline var falling_factorial(double a,
                                  const var& b) {
       return var(new falling_factorial_dv_vari(a, b.vi_));
     }
+
   }
 }
 #endif
