@@ -14,18 +14,18 @@ namespace stan {
       class lmgamma_dv_vari : public op_dv_vari {
       public:
         lmgamma_dv_vari(int a, vari* bvi) :
-          op_dv_vari(stan::math::lmgamma(a, bvi->val_), a, bvi) {
+          op_dv_vari(lmgamma(a, bvi->val_), a, bvi) {
         }
         void chain() {
           double deriv = 0;
           for (int i = 1; i < ad_ + 1; i++)
-            deriv += stan::math::digamma(bvi_->val_ + (1.0 - i) / 2.0);
+            deriv += digamma(bvi_->val_ + (1.0 - i) / 2.0);
           bvi_->adj_ += adj_ * deriv;
         }
       };
     }
 
-    inline var lmgamma(int a, const stan::math::var& b) {
+    inline var lmgamma(int a, const var& b) {
       return var(new lmgamma_dv_vari(a, b.vi_));
     }
 
